@@ -9,7 +9,7 @@ makeRLearner.classif.h2o.randomForest = function() {
       makeLogicalLearnerParam("build_tree_one_node", default = FALSE, tunable = FALSE),
       makeIntegerLearnerParam("ntrees", lower = 1L, default = 50L),
       makeIntegerLearnerParam("max_depth", lower = 1L, default = 20L),
-      makeIntegerLearnerParam("min_rows", lower = 1L,  default = 1L),
+      makeIntegerLearnerParam("min_rows", lower = 1L, default = 1L),
       makeIntegerLearnerParam("nbins", lower = 1L, default = 20L),
       makeIntegerLearnerParam("nbins_cats", lower = 1L, default = 1024L),
       makeLogicalLearnerParam("binomial_double_trees", default = TRUE),
@@ -25,7 +25,7 @@ makeRLearner.classif.h2o.randomForest = function() {
 }
 
 #' @export
-trainLearner.classif.h2o.randomForest = function(.learner, .task, .subset, .weights = NULL,  ...) {
+trainLearner.classif.h2o.randomForest = function(.learner, .task, .subset, .weights = NULL, ...) {
   # check if h2o connection already exists, otherwise start one
   conn.up = tryCatch(h2o::h2o.getConnection(), error = function(err) return(FALSE))
   if (!inherits(conn.up, "H2OConnection")) {
@@ -40,6 +40,7 @@ trainLearner.classif.h2o.randomForest = function(.learner, .task, .subset, .weig
 
 #' @export
 predictLearner.classif.h2o.randomForest = function(.learner, .model, .newdata, ...) {
+
   m = .model$learner.model
   h2of = h2o::as.h2o(.newdata)
   p = h2o::h2o.predict(m, newdata = h2of, ...)
@@ -48,8 +49,9 @@ predictLearner.classif.h2o.randomForest = function(.learner, .model, .newdata, .
   # check if class names are integers. if yes, colnames of p.df need to be adapted
   int = stri_detect_regex(p.df$predict, "^[[:digit:]]+$")
   pcol = stri_detect_regex(colnames(p.df), "^p[[:digit:]]+$")
-  if (any(int) && any(pcol))
+  if (any(int) && any(pcol)) {
     colnames(p.df)[pcol] = stri_sub(colnames(p.df)[pcol], 2L)
+  }
 
   if (.learner$predict.type == "response") {
     return(p.df$predict)
