@@ -5,7 +5,7 @@ makeRLearner.classif.svm = function() {
     package = "e1071",
     par.set = makeParamSet(
       makeDiscreteLearnerParam(id = "type", default = "C-classification", values = c("C-classification", "nu-classification")),
-      makeNumericLearnerParam(id = "cost",  default = 1, lower = 0, requires = quote(type == "C-classification")),
+      makeNumericLearnerParam(id = "cost", default = 1, lower = 0, requires = quote(type == "C-classification")),
       makeNumericLearnerParam(id = "nu", default = 0.5, requires = quote(type == "nu-classification")),
       makeNumericVectorLearnerParam("class.weights", len = NA_integer_, lower = 0),
       makeDiscreteLearnerParam(id = "kernel", default = "radial", values = c("linear", "polynomial", "radial", "sigmoid")),
@@ -29,8 +29,15 @@ makeRLearner.classif.svm = function() {
 
 #' @export
 trainLearner.classif.svm = function(.learner, .task, .subset, .weights = NULL,  ...) {
-  f = getTaskFormula(.task)
-  e1071::svm(f, data = getTaskData(.task, .subset), probability = .learner$predict.type == "prob", ...)
+  if (sum(getTaskDesc(.task)$n.feat[c("factors", "ordered")]) > 0) {
+    # use formula interface if factors are present
+    f = getTaskFormula(.task)
+    e1071::svm(f, data = getTaskData(.task, .subset), probability = .learner$predict.type == "prob", ...)
+  } else {
+    # use the "data.frame" approach if no factors are present to prevent issues like https://github.com/mlr-org/mlr/issues/1738
+    d = getTaskData(.task, .subset, target.extra = TRUE)
+    e1071::svm(d$data, d$target, probability = .learner$predict.type == "prob", ...)
+  }
 }
 
 #' @export
