@@ -10,7 +10,7 @@ makeRLearner.classif.xgboost = function() {
       makeUntypedLearnerParam(id = "watchlist", default = NULL, tunable = FALSE),
       makeNumericLearnerParam(id = "eta", default = 0.3, lower = 0, upper = 1),
       makeNumericLearnerParam(id = "gamma", default = 0, lower = 0),
-      makeIntegerLearnerParam(id = "max_depth", default = 6L, lower = 1L),
+      makeIntegerLearnerParam(id = "max_depth", default = 6L, lower = 0L),
       makeNumericLearnerParam(id = "min_child_weight", default = 1, lower = 0),
       makeNumericLearnerParam(id = "subsample", default = 1, lower = 0, upper = 1),
       makeNumericLearnerParam(id = "colsample_bytree", default = 1, lower = 0, upper = 1),
@@ -23,29 +23,32 @@ makeRLearner.classif.xgboost = function() {
       makeUntypedLearnerParam(id = "eval_metric", default = "error", tunable = FALSE),
       makeNumericLearnerParam(id = "base_score", default = 0.5, tunable = FALSE),
       makeNumericLearnerParam(id = "max_delta_step", lower = 0, default = 0),
-      makeNumericLearnerParam(id = "missing", default = NA, tunable = FALSE, when = "both",
-        special.vals = list(NA, NA_real_, NULL)),
+      makeNumericLearnerParam(id = "missing", default = NA, tunable = FALSE, when = "both", special.vals = list(NA, NA_real_, NULL)),
       makeIntegerVectorLearnerParam(id = "monotone_constraints", default = 0, lower = -1, upper = 1),
       makeNumericLearnerParam(id = "tweedie_variance_power", lower = 1, upper = 2, default = 1.5, requires = quote(objective == "reg:tweedie")),
       makeIntegerLearnerParam(id = "nthread", lower = 1L, tunable = FALSE),
-      makeIntegerLearnerParam(id = "nrounds", default = 1L, lower = 1L),
-      # FIXME nrounds seems to have no default in xgboost(), if it has 1, par.vals is redundant
+      makeIntegerLearnerParam(id = "nrounds", lower = 1L),
       makeUntypedLearnerParam(id = "feval", default = NULL, tunable = FALSE),
       makeIntegerLearnerParam(id = "verbose", default = 1L, lower = 0L, upper = 2L, tunable = FALSE),
-      makeIntegerLearnerParam(id = "print_every_n", default = 1L, lower = 1L, tunable = FALSE,
-        requires = quote(verbose == 1L)),
+      makeIntegerLearnerParam(id = "print_every_n", default = 1L, lower = 1L, tunable = FALSE, requires = quote(verbose == 1L)),
       makeIntegerLearnerParam(id = "early_stopping_rounds", default = NULL, lower = 1L, special.vals = list(NULL), tunable = FALSE),
       makeLogicalLearnerParam(id = "maximize", default = NULL, special.vals = list(NULL), tunable = FALSE),
       makeDiscreteLearnerParam(id = "sample_type", default = "uniform", values = c("uniform", "weighted"), requires = quote(booster == "dart")),
       makeDiscreteLearnerParam(id = "normalize_type", default = "tree", values = c("tree", "forest"), requires = quote(booster == "dart")),
       makeNumericLearnerParam(id = "rate_drop", default = 0, lower = 0, upper = 1, requires = quote(booster == "dart")),
       makeNumericLearnerParam(id = "skip_drop", default = 0, lower = 0, upper = 1, requires = quote(booster == "dart")),
-      # TODO: uncomment the following after the next CRAN update, and set max_depth's lower = 0L
-      # makeLogicalLearnerParam(id = "one_drop", default = FALSE, requires = quote(booster == "dart")),
-      # makeDiscreteLearnerParam(id = "tree_method", default = "exact", values = c("exact", "hist"), requires = quote(booster != "gblinear")),
-      # makeDiscreteLearnerParam(id = "grow_policy", default = "depthwise", values = c("depthwise", "lossguide"), requires = quote(tree_method == "hist")),
-      # makeIntegerLearnerParam(id = "max_leaves", default = 0L, lower = 0L, requires = quote(grow_policy == "lossguide")),
-      # makeIntegerLearnerParam(id = "max_bin", default = 256L, lower = 2L, requires = quote(tree_method == "hist")),
+      makeNumericLearnerParam(id = "scale_pos_weight", default = 1),
+      makeLogicalLearnerParam(id = "refresh_leaf", default = TRUE),
+      makeDiscreteLearnerParam(id = "feature_selector", default = "cyclic", values = c("cyclic", "shuffle", "random", "greedy", "thrifty")),
+      makeIntegerLearnerParam(id = "top_k", default = 0, lower = 0),
+      makeDiscreteLearnerParam(id = "predictor", default = "cpu_predictor", values = c("cpu_predictor", "gpu_predictor")),
+      makeUntypedLearnerParam(id = "updater"), # Default depends on the selected booster
+      makeNumericLearnerParam(id = "sketch_eps", default = 0.03, lower = 0, upper = 1),
+      makeLogicalLearnerParam(id = "one_drop", default = FALSE, requires = quote(booster == "dart")),
+      makeDiscreteLearnerParam(id = "tree_method", default = "exact", values = c("exact", "hist"), requires = quote(booster != "gblinear")),
+      makeDiscreteLearnerParam(id = "grow_policy", default = "depthwise", values = c("depthwise", "lossguide"), requires = quote(tree_method == "hist")),
+      makeIntegerLearnerParam(id = "max_leaves", default = 0L, lower = 0L, requires = quote(grow_policy == "lossguide")),
+      makeIntegerLearnerParam(id = "max_bin", default = 256L, lower = 2L, requires = quote(tree_method == "hist")),
       makeUntypedLearnerParam(id = "callbacks", default = list(), tunable = FALSE)
     ),
     par.vals = list(nrounds = 1L, verbose = 0L),
@@ -63,9 +66,10 @@ trainLearner.classif.xgboost = function(.learner, .task, .subset, .weights = NUL
   td = getTaskDesc(.task)
   parlist = list(...)
   nc = length(td$class.levels)
+  nlvls = length(td$class.levels)
 
   if (is.null(parlist$objective)) {
-    parlist$objective = ifelse(nc == 2L, "binary:logistic", "multi:softprob")
+    parlist$objective = if (nlvls == 2L) "binary:logistic" else "multi:softprob"
   }
 
   if (.learner$predict.type == "prob" && parlist$objective == "multi:softmax") {
@@ -79,6 +83,10 @@ trainLearner.classif.xgboost = function(.learner, .task, .subset, .weights = NUL
 
   task.data = getTaskData(.task, .subset, target.extra = TRUE)
   label = match(as.character(task.data$target), td$class.levels) - 1
+
+  # recode to 0:1 to that for the binary case the positive class translates to 1 (https://github.com/mlr-org/mlr3learners/issues/32)
+  # task.data$target is guaranteed to have the factor levels in the right order
+  label = nlvls - as.integer(task.data$target)
   parlist$data = xgboost::xgb.DMatrix(data = data.matrix(task.data$data), label = label)
 
   if (!is.null(.weights)) {
@@ -97,12 +105,13 @@ predictLearner.classif.xgboost = function(.learner, .model, .newdata, ...) {
 
   td = .model$task.desc
   m = .model$learner.model
-  cls = td$class.levels
+  cls = rev(td$class.levels)
   nc = length(cls)
   obj = .learner$par.vals$objective
+  nlvls = length(cls)
 
   if (is.null(obj)) {
-    .learner$par.vals$objective = ifelse(nc == 2L, "binary:logistic", "multi:softprob")
+    .learner$par.vals$objective = if (nlvls == 2L) "binary:logistic" else "multi:softprob"
   }
 
   p = predict(m, newdata = data.matrix(.newdata), ...)
