@@ -151,7 +151,7 @@
 
 # Details: https://leanpub.com/deeplearning/read
 
-#'@export
+#' @export
 makeRLearner.regr.h2o.deeplearning = function() {
   makeRLearnerRegr(
     cl = "regr.h2o.deeplearning",
@@ -161,7 +161,7 @@ makeRLearner.regr.h2o.deeplearning = function() {
       makeLogicalLearnerParam("use_all_factor_level", default = TRUE),
       makeDiscreteLearnerParam("activation", values = c("Rectifier", "Tanh",
         "TanhWithDropout", "RectifierWithDropout", "Maxout", "MaxoutWithDropout"),
-        default = "Rectifier"),
+      default = "Rectifier"),
       # FIXME: hidden can also be a list of integer vectors for grid search
       makeIntegerVectorLearnerParam("hidden", default = c(200L, 200L),
         len = NA_integer_, lower = 1L),
@@ -189,7 +189,7 @@ makeRLearner.regr.h2o.deeplearning = function() {
       makeDiscreteLearnerParam("loss", values = c("Automatic", "Quadratic",
         "Absolute", "Huber")),
       makeDiscreteLearnerParam("distribution", values = c("AUTO", "gaussian",
-        "bernoulli", "multinomial", "poisson", "gamma", "tweedie", "laplace",
+        "poisson", "gamma", "tweedie", "laplace",
         "huber", "quantile"), default = "AUTO"),
       makeNumericLearnerParam("quantile_alpha", default = 0.5, lower = 0, upper = 1,
         requires = quote(distribution == "quantile")),
@@ -201,9 +201,9 @@ makeRLearner.regr.h2o.deeplearning = function() {
       makeNumericLearnerParam("score_duty_cycle", default = 0.1),
       makeNumericLearnerParam("regression_stop", default = 1e-6, lower = -1),
       makeIntegerLearnerParam("stopping_rounds", default = 5L, lower = 0L),
-      makeDiscreteLearnerParam("stopping_metric", values = c("AUTO", "deviance", "logloss",
-        "MSE", "AUC", "r2", "misclassification"), default = "AUTO",
-        requires = quote(stopping_rounds > 0L)),
+      makeDiscreteLearnerParam("stopping_metric", values = c("AUTO", "deviance",
+        "mse", "rmse", "mae", "rmsle", "r2"), default = "AUTO",
+      requires = quote(stopping_rounds > 0L)),
       makeNumericLearnerParam("stopping_tolerance", default = 0, lower = 0),
       makeNumericLearnerParam("max_runtime_secs", default = 0, lower = 0),
       makeLogicalLearnerParam("quiet_mode", tunable = FALSE),
@@ -223,7 +223,7 @@ makeRLearner.regr.h2o.deeplearning = function() {
       makeLogicalLearnerParam("sparse", default = FALSE, tunable = FALSE),
       makeLogicalLearnerParam("col_major", default = FALSE, tunable = FALSE),
       makeLogicalLearnerParam("average_activation", tunable = FALSE),
-      #makeLogicalLearnerParam("sparsity_beta", tunable = FALSE),
+      # makeLogicalLearnerParam("sparsity_beta", tunable = FALSE),
       makeLogicalLearnerParam("reproducible", default = FALSE, tunable = FALSE),
       makeLogicalLearnerParam("export_weights_and_biases", default = FALSE, tunable = FALSE)
     ),
@@ -237,6 +237,7 @@ makeRLearner.regr.h2o.deeplearning = function() {
 
 #' @export
 trainLearner.regr.h2o.deeplearning = function(.learner, .task, .subset, .weights = NULL, ...) {
+
   # check if h2o connection already exists, otherwise start one
   conn.up = tryCatch(h2o::h2o.getConnection(), error = function(err) return(FALSE))
   if (!inherits(conn.up, "H2OConnection")) {
@@ -262,4 +263,3 @@ predictLearner.regr.h2o.deeplearning = function(.learner, .model, .newdata, ...)
   p.df = as.data.frame(p)
   return(p.df$predict)
 }
-
