@@ -113,11 +113,11 @@ filterFeatures = function(task, method = "randomForestSRC_importance", fval = NU
 
       # caching calls to `generateFilterValuesData()` with the same arguments
       cache.dir = memoise::cache_filesystem(cache.dir)
-      generateFVData = memoise::memoise(generateFilterValuesData, cache = cache.dir)
+      generate.fv.data = memoise::memoise(generateFilterValuesData, cache = cache.dir)
     } else {
-      generateFVData = generateFilterValuesData
+      generate.fv.data = generateFilterValuesData
     }
-    fval = generateFVData(task = task, method = method, nselect = getTaskNFeats(task), ...)$data
+    fval = generate.fv.data(task = task, method = method, nselect = getTaskNFeats(task), ...)$data
   } else {
     assertClass(fval, "FilterValues")
     if (!is.null(fval$method)) { ## fval is generated by deprecated getFilterValues
