@@ -29,24 +29,27 @@
 #' @examples
 #' # see benchmark
 friedmanPostHocTestBMR = function(bmr, measure = NULL, p.value = 0.05, aggregation = "default") {
+
   requirePackages("PMCMR")
   assertClass(bmr, "BenchmarkResult")
   assertNumeric(p.value, lower = 0, upper = 1, len = 1)
   assertChoice(aggregation, c("default", "mean"))
   measure = checkBMRMeasure(measure, bmr)
   n.learners = length(bmr$learners)
-  if (n.learners < 2)
+  if (n.learners < 2) {
     stop("Benchmark results for at least two learners are required")
+  }
   n.tasks = length(bmr$results)
-  if (n.tasks < 2)
+  if (n.tasks < 2) {
     stop("Benchmark results for at least two tasks are required")
+  }
 
   # aggregate over iterations
   if (aggregation == "mean") {
     df = as.data.frame(bmr)
     df = aggregate(df[[measure$id]],
-                   by = list(task.id = df$task.id, learner.id = df$learner.id),
-                   FUN = mean)
+      by = list(task.id = df$task.id, learner.id = df$learner.id),
+      FUN = mean)
     aggr.meas = "x"
   } else if (aggregation == "default") {
     aggr.meas = measureAggrName(measure)
@@ -56,9 +59,10 @@ friedmanPostHocTestBMR = function(bmr, measure = NULL, p.value = 0.05, aggregati
   f.test = friedmanTestBMR(bmr, measure)
   if (!is.na(f.test$p.value)) {
     f.rejnull = f.test$p.value < p.value
-    if (!f.rejnull)
+    if (!f.rejnull) {
       warning("Cannot reject null hypothesis of overall Friedman test,
              returning overall Friedman test.")
+    }
   } else {
     f.rejnull = FALSE
     warning("P-value not computable. Learner performances might be exactly equal.")
