@@ -20,13 +20,11 @@ getFunctionalFeatures.Task = function(object, subset = NULL, features, recode.ta
 
 # @export
 # @rdname getFunctionalFeatures
-getFunctionalFeatures.data.frame = function(object, subset = NULL, features, recode.target = "no"){
+getFunctionalFeatures.data.frame = function(object, subset = NULL, features, recode.target = "no") {
   # Keep only columns with class matrix
   funct.cols = which(vcapply(object, function(x) class(x)[1L]) == "matrix")
-  if (length(funct.cols) == 0L)
+  if (length(funct.cols) == 0L) {
     stop("No functional features in the data")
+  }
   object[, funct.cols, drop = FALSE]
 }
-
-
-
