@@ -33,7 +33,7 @@
 #' @examples
 #' \donttest{
 #' # multi-criteria optimization of (tpr, fpr) with NGSA-II
-#' lrn =  makeLearner("classif.ksvm")
+#' lrn = makeLearner("classif.ksvm")
 #' rdesc = makeResampleDesc("Holdout")
 #' ps = makeParamSet(
 #'   makeNumericParam("C", lower = -12, upper = 12, trafo = function(x) 2^x),
@@ -45,15 +45,18 @@
 #' plotTuneMultiCritResult(res, path = TRUE)
 #' }
 tuneParamsMultiCrit = function(learner, task, resampling, measures, par.set, control, show.info = getMlrOption("show.info"), resample.fun = resample) {
+
   learner = checkLearner(learner)
   assertClass(task, classes = "Task")
   assertList(measures, types = "Measure", min.len = 2L)
   assertClass(par.set, classes = "ParamSet")
   assertClass(control, classes = "TuneMultiCritControl")
-  if (!inherits(resampling, "ResampleDesc") &&  !inherits(resampling, "ResampleInstance"))
+  if (!inherits(resampling, "ResampleDesc") && !inherits(resampling, "ResampleInstance")) {
     stop("Argument resampling must be of class ResampleDesc or ResampleInstance!")
-  if (inherits(resampling, "ResampleDesc") && control$same.resampling.instance)
+  }
+  if (inherits(resampling, "ResampleDesc") && control$same.resampling.instance) {
     resampling = makeResampleInstance(resampling, task = task)
+  }
   assertFlag(show.info)
   control = setDefaultImputeVal(control, measures)
   checkTunerParset(learner, par.set, measures, control)
@@ -75,10 +78,8 @@ tuneParamsMultiCrit = function(learner, task, resampling, measures, par.set, con
     messagef("Imputation value: %g", control$impute.val)
   }
   or = sel.func(learner, task, resampling, measures, par.set, control, opt.path, show.info, resample.fun)
-  if (show.info)
+  if (show.info) {
     messagef("[Tune] Result: Points on front : %i", length(or$x))
+  }
   return(or)
 }
-
-
-
