@@ -1,6 +1,5 @@
 # learner with error "foo" in predict
-makeRLearner.classif.__mlrmocklearners__1 = function() {
-  # nolint
+makeRLearner.classif.__mlrmocklearners__1 = function() { #nolint
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__1", package = character(0L), par.set = makeParamSet(),
     properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob")
@@ -13,7 +12,7 @@ registerS3method("trainLearner", "classif.__mlrmocklearners__1", trainLearner.cl
 registerS3method("predictLearner", "classif.__mlrmocklearners__1", predictLearner.classif.__mlrmocklearners__1)
 
 # for tuning, produces errors en masse
-makeRLearner.classif.__mlrmocklearners__2 = function() {
+makeRLearner.classif.__mlrmocklearners__2 = function() { #nolint
   # nolint
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__2", package = character(0L),
@@ -23,15 +22,13 @@ makeRLearner.classif.__mlrmocklearners__2 = function() {
     properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob")
   )
 }
-trainLearner.classif.__mlrmocklearners__2 = function(.learner, .task, .subset, .weights = NULL, alpha, ...) {
-  # nolint
+trainLearner.classif.__mlrmocklearners__2 = function(.learner, .task, .subset, .weights = NULL, alpha, ...) { #nolint
   if (alpha < 0.5) {
     stop("foo")
   }
   list()
 }
-predictLearner.classif.__mlrmocklearners__2 = function(.learner, .model, .newdata, ...) {
-  # nolint
+predictLearner.classif.__mlrmocklearners__2 = function(.learner, .model, .newdata, ...) { #nolint
   as.factor(sample(.model$task.desc$class.levels, nrow(.newdata), replace = TRUE))
 }
 registerS3method("makeRLearner", "classif.__mlrmocklearners__2", makeRLearner.classif.__mlrmocklearners__2)
@@ -40,8 +37,8 @@ registerS3method("predictLearner", "classif.__mlrmocklearners__2", predictLearne
 
 
 # learner with error "foo" in train
-makeRLearner.classif.__mlrmocklearners__3 = function() {
-  # nolint
+makeRLearner.classif.__mlrmocklearners__3 = function() { #nolint
+
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__3", package = character(0L), par.set = makeParamSet(),
     properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob")
@@ -54,8 +51,8 @@ registerS3method("trainLearner", "classif.__mlrmocklearners__3", trainLearner.cl
 registerS3method("predictLearner", "classif.__mlrmocklearners__3", predictLearner.classif.__mlrmocklearners__3)
 
 # learner with different "when" settings for hyperpars
-makeRLearner.regr.__mlrmocklearners__4 = function() {
-  # nolint
+makeRLearner.regr.__mlrmocklearners__4 = function() { #nolint
+
   makeRLearnerRegr(
     cl = "regr.__mlrmocklearners__4", package = character(0L),
     par.set = makeParamSet(
@@ -67,13 +64,13 @@ makeRLearner.regr.__mlrmocklearners__4 = function() {
   )
 }
 
-trainLearner.regr.__mlrmocklearners__4 = function(.learner, .task, .subset, .weights = NULL, p1, p3, ...) {
-  # nolint
+trainLearner.regr.__mlrmocklearners__4 = function(.learner, .task, .subset, .weights = NULL, p1, p3, ...) { #nolint
+
   list(foo = p1 + p3)
 }
 
-predictLearner.regr.__mlrmocklearners__4 = function(.learner, .model, .newdata, p2, p3) {
-  # nolint
+predictLearner.regr.__mlrmocklearners__4 = function(.learner, .model, .newdata, p2, p3) { #nolint
+
   y = rep(1, nrow(.newdata))
   y * .model$learner.model$foo + p2 + p3
 }
@@ -83,8 +80,8 @@ registerS3method("predictLearner", "regr.__mlrmocklearners__4", predictLearner.r
 
 
 # Learner cannot use expression in param requires
-makeRLearner.classif.__mlrmocklearners__5 = function() {
-  # nolint
+makeRLearner.classif.__mlrmocklearners__5 = function() { #nolint
+
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__5",
     package = "mlr",
@@ -96,11 +93,11 @@ makeRLearner.classif.__mlrmocklearners__5 = function() {
   )
 }
 
-trainLearner.classif.__mlrmocklearners__5 = function(.learner, .task, .subset, .weights = NULL, ...) {
-} # nolint
+trainLearner.classif.__mlrmocklearners__5 = function(.learner, .task, .subset, .weights = NULL, ...) { #nolint
+}
+
+predictLearner.classif.__mlrmocklearners__5 = function(.learner, .model, .newdata) { #nolint
 
-predictLearner.classif.__mlrmocklearners__5 = function(.learner, .model, .newdata) {
-  # nolint
   rep(factor(.model$factor.levels[[.model$task.desc$target]][1]), nrow(.newdata))
 }
 registerS3method("makeRLearner", "classif.__mlrmocklearners__5", makeRLearner.classif.__mlrmocklearners__5)
@@ -108,8 +105,8 @@ registerS3method("trainLearner", "classif.__mlrmocklearners__5", trainLearner.cl
 registerS3method("predictLearner", "classif.__mlrmocklearners__5", predictLearner.classif.__mlrmocklearners__5)
 
 # stores weights internally so we can see wether they are correctly passed down
-makeRLearner.regr.__mlrmocklearners__6 = function() {
-  # nolint
+makeRLearner.regr.__mlrmocklearners__6 = function() { #nolint
+
   makeRLearnerRegr(
     cl = "regr.__mlrmocklearners__6", package = character(0L),
     par.set = makeParamSet(),
@@ -117,21 +114,21 @@ makeRLearner.regr.__mlrmocklearners__6 = function() {
   )
 }
 
-trainLearner.regr.__mlrmocklearners__6 = function(.learner, .task, .subset, .weights = NULL, ...) {
-  # nolint
+trainLearner.regr.__mlrmocklearners__6 = function(.learner, .task, .subset, .weights = NULL, ...) { #nolint
+
   list(weights = .weights)
 }
 
-predictLearner.regr.__mlrmocklearners__6 = function(.learner, .model, .newdata) {
-  # nolint
+predictLearner.regr.__mlrmocklearners__6 = function(.learner, .model, .newdata) { #nolint
+
   rep(1, nrow(.newdata))
 }
 registerS3method("makeRLearner", "regr.__mlrmocklearners__6", makeRLearner.regr.__mlrmocklearners__6)
 registerS3method("trainLearner", "regr.__mlrmocklearners__6", trainLearner.regr.__mlrmocklearners__6)
 registerS3method("predictLearner", "regr.__mlrmocklearners__6", predictLearner.regr.__mlrmocklearners__6)
 
-makeRLearner.classif.__mlrmocklearners__6 = function() {
-  # nolint
+makeRLearner.classif.__mlrmocklearners__6 = function() { #nolint
+
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__6", package = character(0L),
     par.set = makeParamSet(),
@@ -139,13 +136,13 @@ makeRLearner.classif.__mlrmocklearners__6 = function() {
   )
 }
 
-trainLearner.classif.__mlrmocklearners__6 = function(.learner, .task, .subset, .weights = NULL, ...) {
-  # nolint
+trainLearner.classif.__mlrmocklearners__6 = function(.learner, .task, .subset, .weights = NULL, ...) { #nolint
+
   list(weights = .weights)
 }
 
-predictLearner.classif.__mlrmocklearners__6 = function(.learner, .model, .newdata) {
-  # nolint
+predictLearner.classif.__mlrmocklearners__6 = function(.learner, .model, .newdata) { #nolint
+
   rep(1, nrow(.newdata))
 }
 registerS3method("makeRLearner", "classif.__mlrmocklearners__6", makeRLearner.classif.__mlrmocklearners__6)
