@@ -60,7 +60,6 @@ test_that("makeFunctionalData subsetting works", {
 })
 
 test_that("makeFunctionalData works for different inputs", {
-
   df = data.frame(matrix(rnorm(50), nrow = 5))
   # for 1-D matricies
   fdf = makeFunctionalData(df, fd.features = list("fd1" = 1, "fd2" = 2:10))
@@ -135,7 +134,6 @@ test_that("getFunctionalFeatures works for different inputs", {
 
 
 test_that("makeFunctionalData Tasks work", {
-
   df = data.frame(matrix(rnorm(50), nrow = 5))
   df$tcl = as.factor(letters[1:5])
   df$treg = 1:5
@@ -197,12 +195,10 @@ test_that("makeFunctionalData Tasks work", {
   expect_equal(subs.clust2$task.desc$n.feat["numerics"], c("numerics" = 1L))
   expect_equal(subs.clust2$task.desc$n.feat["ordered"], c("ordered" = 0L))
   expect_equal(subs.clust2$task.desc$size, 5L)
-
 })
 
 
 test_that("getTaskData for functionals", {
-
   df = data.frame(matrix(rnorm(50), nrow = 5))
   df$tcl = as.factor(letters[1:5])
   df$treg = 1:5
@@ -210,7 +206,9 @@ test_that("getTaskData for functionals", {
 
   # For a classification
   clt = makeClassifTask(data = fdf, target = "tcl")
-  expect_message({tdata1 = getTaskData(clt, functionals.as = "dfcols")}, "have been converted to numerics")
+  expect_message({
+    tdata1 = getTaskData(clt, functionals.as = "dfcols")
+  }, "have been converted to numerics")
   expect_true(!("matrix" %in% lapply(tdata1, class)))
   expect_equal(tdata1[, getTaskTargetNames(clt)], as.factor(letters[1:5]))
 
@@ -223,21 +221,24 @@ test_that("getTaskData for functionals", {
   expect_equal(tdata3$target, as.factor(letters[1:5]))
   expect_true("matrix" %in% unlist(lapply(tdata3$data, class)))
 
-  expect_message({tdata4 = getTaskData(clt, functionals.as = "dfcols", target.extra = TRUE)})
+  expect_message({
+    tdata4 = getTaskData(clt, functionals.as = "dfcols", target.extra = TRUE)
+  })
   expect_true(!("matrix" %in% lapply(tdata4$data, class)))
   expect_equal(tdata4$target, as.factor(letters[1:5]))
 
 
   # For clustering task
   clustt = makeClusterTask(data = fdf)
-  expect_message({tdatacl1 = getTaskData(clustt, functionals.as = "dfcols")}, "have been converted to numerics")
+  expect_message({
+    tdatacl1 = getTaskData(clustt, functionals.as = "dfcols")
+  }, "have been converted to numerics")
   expect_true(!("matrix" %in% lapply(tdatacl1, class)))
   tdatacl2 = getTaskData(clustt, functionals.as = "matrix")
   expect_true("matrix" %in% unlist(lapply(tdatacl2, class)))
 })
 
 test_that("changeData for functionals", {
-
   df = data.frame(matrix(rnorm(50), nrow = 5))
   df$tcl = as.factor(letters[1:5])
   df$treg = 1:5
@@ -258,7 +259,6 @@ test_that("changeData for functionals", {
 })
 
 test_that("makeFunctionalData produces valid error messages", {
-
   df = data.frame("x" = 1:3, "y" = 2:4, "z" = letters[1:3])
   expect_error(makeFunctionalData(df, fd.features = list("fd1" = 1:4)), "Must be a subset of")
   expect_error(makeFunctionalData(df, fd.features = list("fd1" = 1:3)), "contains non-integer")
@@ -300,8 +300,7 @@ test_that("makeFunctionalData produces valid error messages", {
   expect_equal(dim(fdf5$fd1), c(3, 1))
 
   expect_error(makeFunctionalData(data.frame(matrix(letters[1:9], nrow = 3)),
-                                  fd.features = list("fd1" = 1:3)), "fd.features contains non-integer")
-
+    fd.features = list("fd1" = 1:3)), "fd.features contains non-integer")
 })
 
 
@@ -316,23 +315,30 @@ test_that("hasFunctionals works", {
 })
 
 test_that("getTaskData for functional tasks", {
-
   expect_true(hasFunctionalFeatures(getTaskData(fda.binary.gp.task, functionals.as = "matrix")))
-  expect_message({df = getTaskData(fda.binary.gp.task, subset = 1:50, functionals.as = "dfcols")})
+  expect_message({
+    df = getTaskData(fda.binary.gp.task, subset = 1:50, functionals.as = "dfcols")
+  })
   expect_false(hasFunctionalFeatures(df))
 
   # Subset rows
   expect_true(hasFunctionalFeatures(getTaskData(fda.binary.gp.task, subset = 1:50, functionals.as = "matrix")))
-  expect_message({df = getTaskData(fda.binary.gp.task, subset = 1:50, functionals.as = "dfcols")})
+  expect_message({
+    df = getTaskData(fda.binary.gp.task, subset = 1:50, functionals.as = "dfcols")
+  })
   expect_false(hasFunctionalFeatures(df))
 
   # We can not really subset cols for this task.
   expect_false(hasFunctionalFeatures(getTaskData(fda.regr.fs.task, features = 1, functionals.as = "matrix")))
   expect_true(hasFunctionalFeatures(getTaskData(fda.regr.fs.task, features = 2, functionals.as = "matrix")))
   expect_true(hasFunctionalFeatures(getTaskData(fda.regr.fs.task, features = 3, functionals.as = "matrix")))
-  expect_silent({df = getTaskData(fda.regr.fs.task, features = 1, functionals.as = "dfcols")})
+  expect_silent({
+    df = getTaskData(fda.regr.fs.task, features = 1, functionals.as = "dfcols")
+  })
   expect_false(hasFunctionalFeatures(df))
-  expect_message({df = getTaskData(fda.regr.fs.task, features = c(2, 3), functionals.as = "dfcols")})
+  expect_message({
+    df = getTaskData(fda.regr.fs.task, features = c(2, 3), functionals.as = "dfcols")
+  })
   expect_false(hasFunctionalFeatures(df))
 
 
@@ -340,19 +346,23 @@ test_that("getTaskData for functional tasks", {
   expect_error(hasFunctionalFeatures(getTaskData(fda.binary.gp.task, features = 2, functionals.as = "dfcols")))
 
   expect_false(hasFunctionalFeatures(getTaskData(iris.task, functionals.as = "matrix")))
-  expect_silent({df = getTaskData(iris.task, subset = 1:50, functionals.as = "matrix")})
+  expect_silent({
+    df = getTaskData(iris.task, subset = 1:50, functionals.as = "matrix")
+  })
   expect_false(hasFunctionalFeatures(df))
   expect_false(hasFunctionalFeatures(getTaskData(iris.task, functionals.as = "dfcols")))
-  expect_silent({df = getTaskData(iris.task, subset = 1:50, functionals.as = "dfcols")})
+  expect_silent({
+    df = getTaskData(iris.task, subset = 1:50, functionals.as = "dfcols")
+  })
   expect_false(hasFunctionalFeatures(df))
-
 })
 
 
 test_that("benchmarking on fda tasks works", {
-
   lrns = list(makeLearner("classif.fdausc.knn"), makeLearner("classif.rpart"), makeLearner("classif.featureless"))
-  expect_message({bmr = benchmark(lrns, fda.binary.gp.task.small, cv2)},  "Functional features have been")
+  expect_message({
+    bmr = benchmark(lrns, fda.binary.gp.task.small, cv2)
+  }, "Functional features have been")
   expect_class(bmr, "BenchmarkResult")
   expect_equal(names(bmr$results$gp.fdf), c("classif.fdausc.knn", "classif.rpart", "classif.featureless"))
   expect_numeric(as.data.frame(bmr)$mmce, lower = 0L, upper = 1L)
@@ -361,7 +371,9 @@ test_that("benchmarking on fda tasks works", {
   # Test benchmark mixed learners regression
   set.seed(getOption("mlr.debug.seed"))
   lrns2 = list(makeLearner("regr.FDboost"), makeLearner("regr.rpart"), makeLearner("regr.featureless"))
-  expect_message({bmr2 = benchmark(lrns2, fda.regr.fs.task, hout)}, "Functional features have been")
+  expect_message({
+    bmr2 = benchmark(lrns2, fda.regr.fs.task, hout)
+  }, "Functional features have been")
   expect_class(bmr2, "BenchmarkResult")
   expect_equal(names(bmr2$results$fs.fdf), c("regr.FDboost", "regr.rpart", "regr.featureless"))
   expect_numeric(as.data.frame(bmr2)$mse, lower = 0L, upper = Inf)
@@ -371,7 +383,7 @@ test_that("benchmarking on fda tasks works", {
 test_that("makeFunctionalData for matricies contained in data.frame", {
   df = getTaskData(fuelsubset.task, functionals.as = "matrix")
   df2 = makeFunctionalData(df, fd.features = list("UVVIS" = "UVVIS", "NIR" = "NIR"),
-                     exclude.cols = c("heatan", "h20"))
+    exclude.cols = c("heatan", "h20"))
   expect_equivalent(df, df2)
 
   df = data.frame(matrix(rnorm(100), ncol = 10L))
