@@ -78,13 +78,13 @@ test_that("getClassWeightParam", {
   ps = lrn$par.set$pars[[lrn$class.weights.param]]
 
   # wrapped learner
-  lrnWrap = makeBaggingWrapper(lrn)
+  lrn.wrap = makeBaggingWrapper(lrn)
   expect_equal(ps, getClassWeightParam(lrn))
 
   # model multiplexer with at least 1 learner without class.weight prop
-  modMult = makeModelMultiplexer(list(lrn, makeLearner("classif.rpart")))
+  mod.mult = makeModelMultiplexer(list(lrn, makeLearner("classif.rpart")))
 
-  expect_error(getClassWeightParam(modMult), "please specify one of the base learners: classif.ksvm, classif.rpart")
-  expect_error(getClassWeightParam(modMult, "classif.fu"), "classif.fu is not a base learner. Available base learners are: classif.ksvm, classif.rpart")
-  expect_equal(getClassWeightParam(modMult, "classif.ksvm"), ps)
+  expect_error(getClassWeightParam(mod.mult), "please specify one of the base learners: classif.ksvm, classif.rpart")
+  expect_error(getClassWeightParam(mod.mult, "classif.fu"), "classif.fu is not a base learner. Available base learners are: classif.ksvm, classif.rpart")
+  expect_equal(getClassWeightParam(mod.mult, "classif.ksvm"), ps)
 })
