@@ -30,8 +30,8 @@ test_that("listLearners printer (#1336)", {
   width = getOption("width")
   options(width = 1000)
   out = capture.output(print(x1), file = NULL)
-  expect_equal(length(stri_match_all(out, regex = "\n")), 8)
-  out = capture.output(print(x1, n = 10), file = NULL)
-  expect_equal(length(stri_match_all(out, regex = "\n")), 12)
+  expect_equal(length(stri_match_all(out, regex = "\n")), 334)
+  out = capture.output(head(x1, n = 10), file = NULL)
+  expect_equal(length(stri_match_all(out, regex = "\n")), 11)
   options(width = width)
 })
