@@ -55,16 +55,16 @@ test_that("getResamplingIndices(inner = TRUE) correctly translates the inner ind
   ps = makeParamSet(makeIntegerParam("num.trees", lower = 50, upper = 70))
   inner = makeResampleDesc("CV", fixed = TRUE)
   outer = makeResampleDesc("CV", fixed = TRUE)
-  tune_wrapper = makeTuneWrapper(lrn, resampling = inner, par.set = ps,
+  tune.wrapper = makeTuneWrapper(lrn, resampling = inner, par.set = ps,
     control = ctrl, show.info = FALSE)
-  p = resample(tune_wrapper, ct, outer, show.info = FALSE,
+  p = resample(tune.wrapper, ct, outer, show.info = FALSE,
     extract = getTuneResult)
 
-  inner_inds = getResamplingIndices(p, inner = TRUE)
+  inner.inds = getResamplingIndices(p, inner = TRUE)
 
   # to test we expect that any inner fold contains indices that exceed $obs - (obs / nfolds)$ = 150 - 30 = 120
   # 120 is the max index number that is used in the inner resampling (in the case of 150 obs and 5 folds) because we have one fold less than in the outer level
-  inds = sort(inner_inds[[2]][["test.inds"]][[1]])
+  inds = sort(inner.inds[[2]][["test.inds"]][[1]])
 
   expect_equal(length(inds[inds > 120]), 30)
 })
