@@ -14,7 +14,7 @@ test_that("classif_LiblineaRL2L1SVC", {
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1L:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     pars = list(data = binaryclass.train[, -binaryclass.class.col],
       target = binaryclass.train[, binaryclass.target], type = 3L)
@@ -28,5 +28,4 @@ test_that("classif_LiblineaRL2L1SVC", {
 
   testSimpleParsets("classif.LiblineaRL2L1SVC", binaryclass.df, binaryclass.target,
     binaryclass.train.inds, old.predicts.list, parset.list)
-
 })
