@@ -14,8 +14,7 @@ test_that("classif_fdausc.kernel behaves like original api", {
 
   mtest = phoneme[["test"]]
   gtest = phoneme[["classtest"]]
-  set.seed(getOption("mlr.debug.seed"))
-  a1 = fda.usc::classif.kernel(glearn, mlearn)
+  a1 = suppressWarnings(fda.usc::classif.kernel(glearn, mlearn))
   p1 = predict(a1, mtest)
   p2 = predict(a1, mlearn)
 
@@ -29,13 +28,13 @@ test_that("classif_fdausc.kernel behaves like original api", {
   fdata = makeFunctionalData(ph, fd.features = NULL, exclude.cols = "label")
   ftest = makeFunctionalData(phtst, fd.features = NULL, exclude.cols = "label")
   task = makeClassifTask(data = fdata, target = "label")
-  set.seed(getOption("mlr.debug.seed"))
   m = train(lrn, task)
   cp = predict(m, newdata = ftest)
   cp = unlist(cp$data$response, use.names = FALSE)
 
   cp2 = predict(m, newdata = fdata)
   cp2 = unlist(cp2$data$response, use.names = FALSE)
+
   # check if the output from the original API matches the mlr learner's output
   expect_equal(as.character(cp2), as.character(p2))
   expect_equal(as.character(cp), as.character(p1))
@@ -45,7 +44,6 @@ test_that("predicttype prob for fda.usc", {
   requirePackagesOrSkip("fda.usc", default.method = "load")
   lrn = makeLearner("classif.fdausc.kernel", predict.type = "prob")
 
-  set.seed(getOption("mlr.debug.seed"))
   m = train(lrn, fda.binary.gp.task)
   cp = predict(m, newdata = getTaskData(fda.binary.gp.task, target.extra = TRUE, functionals.as = "matrix")$data)
   expect_equal(class(cp)[1], "PredictionClassif")
@@ -55,7 +53,6 @@ test_that("resampling fdausc.kernel", {
   requirePackagesOrSkip("fda.usc", default.method = "load")
   lrn = makeLearner("classif.fdausc.kernel", par.vals = list(trim = 0.5), predict.type = "prob")
 
-  set.seed(getOption("mlr.debug.seed"))
   r = resample(lrn, fda.binary.gp.task.small, cv2)
   expect_class(r, "ResampleResult")
 })
