@@ -35,12 +35,19 @@ test_that("classif_gbm", {
   set.seed(getOption("mlr.debug.seed"))
   m = gbm::gbm(multiclass.formula, data = multiclass.train, n.trees = 300, interaction.depth = 2, distribution = "multinomial")
   p = gbm::predict.gbm(m, newdata = multiclass.test, n.trees = 300)
-  y = factor(apply(p[, , 1], 1, function(r) colnames(p)[which.max(r)]))
+  y = factor(apply(array(c(p), dim(p)[-3], dimnames = dimnames(p)[1:2]), 1, function(r) colnames(p)[which.max(r)]))
   testSimple("classif.gbm", multiclass.df, multiclass.target, multiclass.train.inds, y,
     parset = list(n.trees = 300, interaction.depth = 2, distribution = "multinomial"))
 })
 
 test_that("classif_gbm keep.data is passed correctly", {
-  train(makeLearner("classif.gbm", keep.data = FALSE), binaryclass.task)
-  train(makeLearner("classif.gbm", keep.data = TRUE), binaryclass.task)
+  expect_silent(train(makeLearner("classif.gbm", keep.data = FALSE), binaryclass.task))
+  expect_silent(train(makeLearner("classif.gbm", keep.data = TRUE), binaryclass.task))
+})
+
+# issue https://github.com/mlr-org/mlr/issues/2673
+test_that("prediction values of newdata with only one row are handled correctly", {
+  lrn = makeLearner("classif.gbm", predict.type = "prob")
+  model = train(lrn, iris.task)
+  expect_s3_class(predict(model, newdata = iris[1, ]), "Prediction")
 })
