@@ -4,7 +4,9 @@ test_that("classif_multinom", {
   requirePackagesOrSkip("nnet", default.method = "load")
 
   set.seed(getOption("mlr.debug.seed"))
-  capture.output({m = nnet::multinom(formula = multiclass.formula, data = multiclass.train)})
+  capture.output({
+    m = nnet::multinom(formula = multiclass.formula, data = multiclass.train)
+  })
 
   set.seed(getOption("mlr.debug.seed"))
   p = predict(m, newdata = multiclass.test)
