@@ -6,18 +6,25 @@ test_that("filterFeatures_praznik", {
   c = c(TRUE, TRUE, TRUE, FALSE, TRUE, FALSE) # logical vector
   d = c(1L, 3L, 5L, 7L, 9L, 17L)
   f = rep(c("c1", "c2"), 9)
-  df = data.frame(a = a, b = b, c = c, d = d, f = f, const1 = f, const2 = a)
-  df = convertDataFrameCols(df, logicals.as.factor = TRUE)
-  task = makeClassifTask(data = df, target = "f")
+  df = data.frame(a = a, b = b, c = c, d = d, target = f)
+  df = convertDataFrameCols(df, logicals.as.factor = TRUE) # makeClassifTask does not support logicals
+  task = makeClassifTask(data = df, target = "target")
 
   candidates = as.character(listFilterMethods()$id)
   candidates = candidates[startsWith(candidates, "praznik_")]
   for (candidate in candidates) {
     fv = generateFilterValuesData(task, method = candidate, nselect = 2L)
     expect_class(fv, "FilterValues")
-    expect_data_frame(fv$data, nrow = getTaskNFeats(task))
+    # New CMIM engine since praznik v7.0.0
+    # a return value for 'c' was actually a bug for <= 7.0.0
+    # see https://gitlab.com/mbq/praznik/issues/19
+    if (candidate == "praznik_CMIM") {
+      expect_equal(sum(!is.na(fv$data$value)), 1, info = candidate)
+    } else {
+      expect_equal(sum(!is.na(fv$data$value)), 2, info = candidate)
+    }
+    expect_data_frame(fv$data, nrows = getTaskNFeats(task))
     expect_set_equal(fv$data$name, getTaskFeatureNames(task))
-    expect_equal(sum(!is.na(fv$data$value)), 2L)
     expect_numeric(fv$data$value, lower = 0, upper = 1, all.missing = FALSE)
 
     lrn = makeLearner("classif.featureless")
