@@ -6,13 +6,13 @@ test_that("no crash with sffs", {
   dataset = as.data.frame(p)
   dataset = droplevels(subset(dataset, classes != 3))
 
-  mCT = makeClassifTask(data = dataset, target = "classes")
+  m.ct = makeClassifTask(data = dataset, target = "classes")
   ctrl = makeFeatSelControlSequential(method = "sffs", maxit = NA, alpha = 0.001)
-  mL = makeLearner("classif.logreg", predict.type = "prob")
+  m.l = makeLearner("classif.logreg", predict.type = "prob")
   inner = makeResampleDesc("Holdout", stratify = TRUE)
-  lrn = makeFeatSelWrapper(mL, resampling = inner, control = ctrl)
+  lrn = makeFeatSelWrapper(m.l, resampling = inner, control = ctrl)
   outer = makeResampleDesc("CV", iters = 2, stratify = TRUE)
   # No error occurs
-  expect_error(resample(lrn, mCT, outer, extract = getFeatSelResult, measures = list(mlr::auc, mlr::acc, mlr::brier), models = TRUE),
+  expect_error(resample(lrn, m.ct, outer, extract = getFeatSelResult, measures = list(mlr::auc, mlr::acc, mlr::brier), models = TRUE),
     NA)
 })
