@@ -4,16 +4,16 @@ n = 50L
 p = 2L
 mydata1 = matrix(runif(2 * n * p), nrow = 2 * n, ncol = p)
 mydata1 = as.data.frame(mydata1)
-mydata1[1:n, ]  = mydata1[1:n, ] + 10L
-mydata1[(n + 1):(2 * n), ]  = mydata1[(n + 1):(2 * n), ] - 10L
+mydata1[1:n, ] = mydata1[1:n, ] + 10L
+mydata1[(n + 1):(2 * n), ] = mydata1[(n + 1):(2 * n), ] - 10L
 mydata1$y = factor(rep(c("a", "b"), each = c(n)))
 mydata2 = mydata1
 mydata2$y = factor(rep(c("a", "b"), each = c(n)), levels = c("b", "a"))
 
 mydata3 = matrix(runif(3 * n * p), nrow = 3 * n, ncol = p)
 mydata3 = as.data.frame(mydata3)
-mydata3[1:n, ]  = mydata3[1:n, ] + 10L
-mydata3[(n + 1):(2 * n), ]  = mydata3[(n + 1):(2 * n), ] - 10L
+mydata3[1:n, ] = mydata3[1:n, ] + 10L
+mydata3[(n + 1):(2 * n), ] = mydata3[(n + 1):(2 * n), ] - 10L
 mydata3$y = factor(rep(c("a", "b", "c"), each = c(n)))
 mydata4 = mydata3
 mydata4$y = factor(rep(c("a", "b", "c"), each = c(n)), levels = c("c", "b", "a"))
@@ -22,8 +22,8 @@ mytask1a = makeClassifTask(id = "t1a", data = mydata1, target = "y", positive =
 mytask1b = makeClassifTask(id = "t1b", data = mydata1, target = "y", positive = "b")
 mytask2a = makeClassifTask(id = "t2a", data = mydata2, target = "y", positive = "a")
 mytask2b = makeClassifTask(id = "t2b", data = mydata2, target = "y", positive = "b")
-mytask3 =  makeClassifTask(id = "t3",  data = mydata3, target = "y")
-mytask4 =  makeClassifTask(id = "t4",  data = mydata4, target = "y")
+mytask3 = makeClassifTask(id = "t3", data = mydata3, target = "y")
+mytask4 = makeClassifTask(id = "t4", data = mydata4, target = "y")
 
 hpars = list(
   classif.bartMachine = list(verbose = FALSE, run_in_sample = FALSE,
@@ -46,6 +46,7 @@ test_that("no labels are switched", {
 
 
   checkErrsForTask = function(task, predtype) {
+
     props = if (predtype == "response") character(0L) else "prob"
     lrns = listLearners(task, create = TRUE, properties = props)
     lids = extractSubList(lrns, "id")
@@ -57,13 +58,15 @@ test_that("no labels are switched", {
     lrns = lrns[!toremove]
 
     vnapply(lrns, function(lrn) {
+
       lrn = setPredictType(lrn, predtype)
       id = lrn$id
       hps = hpars[[id]]
-      if (!is.null(hps))
+      if (!is.null(hps)) {
         lrn = setHyperPars(lrn, par.vals = hps)
+      }
       tmp = holdout(lrn, task, split = 0.5, stratify = TRUE)
-      #print(as.data.frame(getRRPredictions(tmp)))
+      # print(as.data.frame(getRRPredictions(tmp)))
       err = tmp$aggr[[1L]]
       expect_true(!is.na(err) & err <= 1 / 3, info = paste(getTaskDesc(task)$id, id, err, sep = ", "))
       err
