@@ -12,9 +12,9 @@ test_that("multilabel_randomForestSRC", {
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
-    for(j in multilabel.target) {
+    for (j in multilabel.target) {
       multilabel.train[j] = factor(multilabel.train[[j]], levels = c("TRUE", "FALSE"))
       multilabel.test[j] = factor(multilabel.test[[j]], levels = c("TRUE", "FALSE"))
     }
@@ -27,5 +27,5 @@ test_that("multilabel_randomForestSRC", {
     old.probs.list[[i]] = as.data.frame(lapply(p$classOutput, function(x) x$predicted[, 1]))
   }
   testSimpleParsets("multilabel.randomForestSRC", multilabel.df, multilabel.target, multilabel.train.inds, old.predicts.list, parset.list)
-  testProbParsets ("multilabel.randomForestSRC", multilabel.df, multilabel.target, multilabel.train.inds, old.probs.list, parset.list)
+  testProbParsets("multilabel.randomForestSRC", multilabel.df, multilabel.target, multilabel.train.inds, old.probs.list, parset.list)
 })
