@@ -4,11 +4,10 @@ test_that("regr_GPfit", {
   testFun = function(x) {
     return(4 * x[, 1]^2 - 2 * x[, 2])
   }
-  n = 30
-  d = 2
   set.seed(getOption("mlr.debug.seed"))
   train.inds = 1:20
-  x = lhs::maximinLHS(n, d)
+  s = seq(0, 1, by = 0.2)
+  x = expand.grid(s, s)
   y = testFun(x)
   gpfit.test.df = cbind.data.frame(x, y)
   colnames(gpfit.test.df) = c("x1", "x2", "y")
