@@ -12,13 +12,13 @@ test_that("surv_coxph", {
 
   old.predicts.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     pars = list(formula = surv.formula, data = surv.train)
     pars = c(pars, parset)
     set.seed(getOption("mlr.debug.seed"))
     m = do.call(survival::coxph, pars)
-    p  = predict(m, newdata = surv.test, type = "lp")
+    p = predict(m, newdata = surv.test, type = "lp")
     old.predicts.list[[i]] = p
   }
 
